@@ -241,6 +241,6 @@ class Web3:
         self._ens = new_ens
 
     def pubkey_to_address(self, pubkey):
-        addr_dict = {"MAINNET": pubkey.to_bech32_address(),
-                     "TESTNET": pubkey.to_bech32_test_address()}
+        addr_dict = {MIANNETHRP: pubkey.to_bech32_address(),
+                     TESTNETHRP: pubkey.to_bech32_test_address()}
         return addr_dict[self.net_type]
